@@ -1,12 +1,11 @@
 import boto3
-import pickle
-import logging
+import joblib
 import subprocess
 from trell import aws
 from io import BytesIO
 
-# from trell.utils import LogFormatter
-# LogFormatter.apply()
+from trell.utils import LogFormatter
+LogFormatter.apply()
 
 
 class S3:
@@ -31,7 +30,7 @@ class S3:
         with BytesIO() as data:
             s3.Bucket(bucket).download_fileobj(key, data)
             data.seek(0)
-            old_data = pickle.load(data)
+            old_data = joblib.load(data)
         return old_data
 
     @staticmethod
@@ -45,12 +44,17 @@ class S3:
         :return None
         """
 
-        key = sub_bucket + file_name
-        pickle_byte_obj = pickle.dumps(python_data_object)
-        print("Writing data to : " + bucket + "/" + key)
-        s3_resource = boto3.resource('s3', aws_access_key_id=aws.cred['ACCESS_KEY'],
+        inserted = False
+        key = '{}{}'.format(sub_bucket, file_name)
+        compress = ('gzip', 3)
+        # logging.info("Writing data to : " + bucket + "/" + key)
+        print("Writing data to : " + bucket + '/' + key)
+        s3 = boto3.resource('s3', aws_access_key_id=aws.cred['ACCESS_KEY'],
                                         aws_secret_access_key=aws.cred['SECRET_KEY'])
-        s3_resource.Object(bucket, key).put(Body=pickle_byte_obj)
+        with tempfile.TemporaryFile() as data:
+                    joblib.dump(python_data_object, data, compress=compress)
+                    data.seek(0)
+                    s3.Bucket(bucket).upload_fileobj(data, key)
 
     @staticmethod
     def upload_data_from_local_to_s3(model_file_name, bucket='', sub_bucket=''):
